@@ -43,6 +43,19 @@ Mail::DKIM::Verifier - verifies a DKIM-signed message
   # what is the result of the verify?
   my $result = $dkim->result;
 
+  # there might be multiple signatures, what is the result per signature?
+  foreach my $signature ($dkim->signatures)
+  {
+      print "signature identity: " . $signature->identity . "\n";
+      print "verify result: " . $signature->result_detail . "\n";
+  }
+
+  # the alleged author of the email may specify how to handle email
+  foreach my $policy ($dkim->policies)
+  {
+      die "fraudulent message" if ($policy->apply($dkim) eq "reject");
+  }
+
 =cut
 
 =head1 DESCRIPTION
@@ -54,7 +67,7 @@ message has been completely read, the signatures are verified and the
 results of the verification can be accessed.
 
 To use the verifier, first create the verifier object. Then start
-"feeding" it the email message to be verified. When all the headers
+"feeding" it the email message to be verified. When all the _headers_
 have been read, the verifier:
 
  1. checks whether any DomainKeys/DKIM signatures were found
@@ -62,12 +75,21 @@ have been read, the verifier:
  3. sets up the appropriate algorithms and canonicalization objects
  4. canonicalizes the headers and computes the header hash
 
-Then, when the body of the message has been completely fed into the
+Then, when the _body_ of the message has been completely fed into the
 verifier, the body hash is computed and the signatures are verified.
 
+The results of the verification can be checked with L</"result()">
+or L</"signatures()">.
+
+Messages that do not verify may be checked against the alleged sender's
+published signing policy with L</"policies()"> and
+L<Mail::DKIM::Policy/"apply()">.
+
 =head1 CONSTRUCTOR
 
-=head2 new() - construct an object-oriented verifier
+=head2 new()
+
+Constructs an object-oriented verifier.
 
   my $dkim = Mail::DKIM::Verifier->new();
 
@@ -89,7 +111,7 @@ is written to the referenced string or file handle.
 package Mail::DKIM::Verifier;
 use base "Mail::DKIM::Common";
 use Carp;
-our $VERSION = 0.34;
+our $VERSION = 0.36;
 
 sub init
 {
@@ -478,7 +500,9 @@ sub finish_body
 
 =head1 METHODS
 
-=head2 PRINT() - feed part of the message to the verifier
+=head2 PRINT()
+
+Feeds part of the message to the verifier.
 
   $dkim->PRINT("a line of the message\015\012");
   $dkim->PRINT("more of");
@@ -488,44 +512,18 @@ Feeds content of the message being verified into the verifier.
 The API is designed this way so that the entire message does NOT need
 to be read into memory at once.
 
-=head2 CLOSE() - call this when finished feeding in the message
+=head2 CLOSE()
+
+Call this when finished feeding in the message.
 
   $dkim->CLOSE;
 
 This method finishes the canonicalization process, computes a hash,
 and verifies the signature.
 
-=head2 fetch_author_policy() - retrieves a signing policy from DNS
+=head2 fetch_author_domain_policies()
 
-  my $policy = $dkim->fetch_author_policy;
-  my $policy_result = $policy->apply($dkim);
-
-This method retrieves the DKIM Sender Signing Practices
-record as described in Internet Draft draft-ietf-dkim-ssp-00-01dc.
-This Internet Draft is now obsolete; this method is only kept for
-backward-compatibility purposes.
-
-Please use the L</"policies()"> method instead.
-
-=cut
-
-sub fetch_author_policy
-{
-	my $self = shift;
-	my ($author) = @_;
-	use Mail::DKIM::DkimPolicy;
-
-	# determine address found in the "From"
-	$author ||= $self->message_originator->address;
-
-	# fetch the policy
-	return Mail::DKIM::DkimPolicy->fetch(
-			Protocol => "dns",
-			Author => $author,
-			);
-}
-
-=head2 fetch_author_domain_policies() - retrieves ADSP records from DNS
+Retrieves ADSP records from DNS.
 
   my @policies = $dkim->fetch_author_domain_policies;
   foreach my $policy (@policies)
@@ -567,7 +565,41 @@ sub fetch_author_domain_policies
 		} @authors;
 }
 
-=head2 fetch_sender_policy() - retrieves a signing policy from DNS
+=head2 fetch_author_policy()
+
+Retrieves a signing policy from DNS.
+
+  my $policy = $dkim->fetch_author_policy;
+  my $policy_result = $policy->apply($dkim);
+
+This method retrieves the DKIM Sender Signing Practices
+record as described in Internet Draft draft-ietf-dkim-ssp-00-01dc.
+This Internet Draft is now obsolete; this method is only kept for
+backward-compatibility purposes.
+
+Please use the L</"policies()"> method instead.
+
+=cut
+
+sub fetch_author_policy
+{
+	my $self = shift;
+	my ($author) = @_;
+	use Mail::DKIM::DkimPolicy;
+
+	# determine address found in the "From"
+	$author ||= $self->message_originator->address;
+
+	# fetch the policy
+	return Mail::DKIM::DkimPolicy->fetch(
+			Protocol => "dns",
+			Author => $author,
+			);
+}
+
+=head2 fetch_sender_policy()
+
+Retrieves a signing policy from DNS.
 
   my $policy = $dkim->fetch_sender_policy;
   my $policy_result = $policy->apply($dkim);
@@ -606,7 +638,9 @@ sub fetch_sender_policy
 			);
 }
 
-=head2 load() - load the entire message from a file handle
+=head2 load()
+
+Load the entire message from a file handle.
 
   $dkim->load($file_handle);
 
@@ -614,7 +648,9 @@ Reads a complete message from the designated file handle,
 feeding it into the verifier. The message must use <CRLF> line
 terminators (same as the SMTP protocol).
 
-=head2 message_originator() - access the "From" header
+=head2 message_originator()
+
+Access the "From" header.
 
   my $address = $dkim->message_originator;
 
@@ -630,7 +666,9 @@ To get just the email address part, do:
 
 See also L</"message_sender()">.
 
-=head2 message_sender() - access the "From" or "Sender" header
+=head2 message_sender()
+
+Access the "From" or "Sender" header.
 
   my $address = $dkim->message_sender;
 
@@ -649,7 +687,9 @@ transmission of the message. For example, if a secretary were to send a
 message for another person, the "sender" would be the secretary and
 the "originator" would be the actual author.
 
-=head2 policies() - retrieves applicable signing policies from DNS
+=head2 policies()
+
+Retrieves applicable signing policies from DNS.
 
   my @policies = $dkim->policies;
   foreach my $policy (@policies)
@@ -688,7 +728,9 @@ sub policies
 }
 
 
-=head2 result() - access the result of the verification
+=head2 result()
+
+Access the result of the verification.
 
   my $result = $dkim->result;
 
@@ -727,13 +769,15 @@ Returned if no DKIM-Signature headers (valid or invalid) were found.
 
 In case of multiple signatures, the "best" result will be returned.
 Best is defined as "pass", followed by "fail", "invalid", and "none".
-To examine the results of individual signatures, use the L</signatures>
+To examine the results of individual signatures, use the L</"signatures()">
 method to retrieve the signature objects. See
-L<Mail::DKIM::Signature/result>.
+L<Mail::DKIM::Signature/"result()">.
 
 =cut
 
-=head2 result_detail() - access the result, plus details if available
+=head2 result_detail()
+
+Access the result, plus details if available.
 
   my $detail = $dkim->result_detail;
 
@@ -774,7 +818,9 @@ The following are possible results from the result_detail() method:
   invalid (public key: OpenSSL error: ...)
   none
 
-=head2 signature() - access the message's DKIM signature
+=head2 signature()
+
+Access the message's DKIM signature.
 
   my $sig = $dkim->signature;
 
@@ -787,7 +833,9 @@ Best is defined as "pass", followed by "fail", "invalid", and "none".
 
 =cut
 
-=head2 signatures() - access all of this message's signatures
+=head2 signatures()
+
+Access all of this message's signatures.
 
   my @all_signatures = $dkim->signatures;
 
